aboutsummaryrefslogtreecommitdiff
path: root/gcc/fortran/array.c
diff options
context:
space:
mode:
authorRalf Wildenhues <Ralf.Wildenhues@gmx.de>2008-07-21 19:17:08 +0000
committerRalf Wildenhues <rwild@gcc.gnu.org>2008-07-21 19:17:08 +0000
commitdf2fba9e343385222745d9e99cbaae29026a263d (patch)
treeb4aa45858530c5447d03da6b7e211c2d414973d2 /gcc/fortran/array.c
parent2e7628842865d7de2eeb170af79f0fc38c057d9c (diff)
downloadgcc-df2fba9e343385222745d9e99cbaae29026a263d.zip
gcc-df2fba9e343385222745d9e99cbaae29026a263d.tar.gz
gcc-df2fba9e343385222745d9e99cbaae29026a263d.tar.bz2
fmt_g0_3.f08: Fix typo in expected error message.
gcc/testsuite/ * gfortran.dg/fmt_g0_3.f08: Fix typo in expected error message. gcc/fortran/ * expr.c (gfc_check_pointer_assign): Fix typo in string. * io.c (check_format): Fix typo in string. Fix comment typos. * parse.c (gfc_global_used): Likewise. * resolve.c (resolve_allocate_expr): Likewise. * symbol.c (gfc_set_default_type): Likewise. * arith.c: Fix typos in comments. * array.c: Likewise. * data.c: Likewise. * decl.c: Likewise. * dependency.c: Likewise. * f95-lang.c: Likewise. * gfortran.h: Likewise. * matchexp.c: Likewise. * module.c: Likewise. * primary.c: Likewise. * scanner.c: Likewise. * trans-array.c: Likewise. * trans-common.c: Likewise. * trans-decl.c: Likewise. * trans-expr.c: Likewise. * trans-intrinsic.c: Likewise. * trans-types.c: Likewise. * trans.c: Likewise. * trans.h: Likewise. From-SVN: r138040
Diffstat (limited to 'gcc/fortran/array.c')
-rw-r--r--gcc/fortran/array.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc/fortran/array.c b/gcc/fortran/array.c
index ab9e428..7216d1f 100644
--- a/gcc/fortran/array.c
+++ b/gcc/fortran/array.c
@@ -1577,7 +1577,7 @@ resolve_array_list (gfc_constructor *p)
}
/* Resolve character array constructor. If it has a specified constant character
- length, pad/trunkate the elements here; if the length is not specified and
+ length, pad/truncate the elements here; if the length is not specified and
all elements are of compile-time known length, emit an error as this is
invalid. */
@@ -1675,7 +1675,7 @@ got_charlen:
max_length only if they pass. */
gfc_extract_int (expr->ts.cl->length, &found_length);
/* Now pad/trunkate the elements accordingly to the specified character
length. This is ok inside this conditional, as in the case above
(without typespec) all elements are verified to have the same length
anyway. */
@@ -1675,7 +1675,7 @@ got_charlen:
max_length only if they pass. */
gfc_extract_int (expr->ts.cl->length, &found_length);
- /* Now pad/trunkate the elements accordingly to the specified character
+ /* Now pad/truncate the elements accordingly to the specified character
length. This is ok inside this conditional, as in the case above
(without typespec) all elements are verified to have the same length